# Welcome to ACES!

ACES is a library designed for the automatic extraction of cohorts from event stream time series datasets.

Check out the {doc}`/usage` for installation instructions and further information on how to extract cohorts!

______________________________________________________________________

## Contents

```{toctree}
---
glob:
maxdepth: 2
---
Overview <overview>
Usage Guide <usage>
Task Examples <notebooks/examples>
Sample Data Tutorial <notebooks/tutorial>
Predicates DataFrame <notebooks/predicates>
Configuration Language <configuration>
Algorithm & Terminology <terminology>
Module API Reference <api/modules>
License <license>
```
